@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,7 +29,7 @@ class KPIMTEXTEDIT_EXPORT RichTextComposerEmailQuoteDecorator : public Sonnet::S
 {
 public:
     explicit RichTextComposerEmailQuoteDecorator(RichTextComposer *textEdit);
-    ~RichTextComposerEmailQuoteDecorator();
+    ~RichTextComposerEmailQuoteDecorator() override;
 
 protected:
     bool isSpellCheckingEnabledForBlock(const QString &blockText) const override;
