@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -114,8 +114,8 @@ void InsertTableWidget::slotTypeOfLengthChanged(int index)
 QTextLength::Type InsertTableWidget::typeOfLength() const
 {
     return
-        (QTextLength::Type)d->mTypeOfLength->itemData(
-        d->mTypeOfLength->currentIndex()).toInt();
+        static_cast<QTextLength::Type>(d->mTypeOfLength->itemData(
+        d->mTypeOfLength->currentIndex()).toInt());
 }
 
 void InsertTableWidget::setTypeOfLength(QTextLength::Type type)
