@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -21,14 +21,12 @@
 #ifndef KPIMTEXTEDIT_TABLECELLFORMATDIALOG_H
 #define KPIMTEXTEDIT_TABLECELLFORMATDIALOG_H
 
-#include "kpimtextedit_export.h"
-
 #include <QDialog>
 
 #include <QTextCharFormat>
 
 namespace KPIMTextEdit {
-class KPIMTEXTEDIT_EXPORT TableCellFormatDialog : public QDialog
+class TableCellFormatDialog : public QDialog
 {
     Q_OBJECT
 public:
@@ -39,7 +37,7 @@ public:
      * @brief tableCellBackgroundColor
      * @return background color of cell.
      */
-    QColor tableCellBackgroundColor() const;
+    Q_REQUIRED_RESULT QColor tableCellBackgroundColor() const;
 
     /**
      * @brief setTableCellBackgroundColor
@@ -51,7 +49,7 @@ public:
      * @brief verticalAlignment
      * @return vertical alignment for current cell.
      */
-    QTextCharFormat::VerticalAlignment verticalAlignment() const;
+    Q_REQUIRED_RESULT QTextCharFormat::VerticalAlignment verticalAlignment() const;
 
     /**
      * @brief setVerticalAlignment
@@ -63,7 +61,7 @@ public:
      * @brief useBackgroundColor
      * @return true if we define background color. Otherwise false and allows to clear it.
      */
-    bool useBackgroundColor() const;
+    Q_REQUIRED_RESULT bool useBackgroundColor() const;
 
 private:
     class TableCellFormatDialogPrivate;
