@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,26 +23,31 @@
 #include "kpimtextedit_export.h"
 
 #include <Sonnet/Highlighter>
-namespace KPIMTextEdit {
-class Rule;
+#include <KSyntaxHighlighting/SyntaxHighlighter>
+
+namespace KSyntaxHighlighting {
+class Format;
 }
 
 namespace KPIMTextEdit {
 class PlainTextEditor;
-class KPIMTEXTEDIT_EXPORT PlainTextSyntaxSpellCheckingHighlighter : public Sonnet::Highlighter
+class PlainTextSyntaxSpellCheckingHighlighterPrivate;
+
+class KPIMTEXTEDIT_EXPORT PlainTextSyntaxSpellCheckingHighlighter : public Sonnet::Highlighter, public KSyntaxHighlighting::AbstractHighlighter
 {
 public:
     explicit PlainTextSyntaxSpellCheckingHighlighter(PlainTextEditor *plainText, const QColor &misspelledColor = Qt::red);
-    ~PlainTextSyntaxSpellCheckingHighlighter();
+    ~PlainTextSyntaxSpellCheckingHighlighter() override;
 
     void toggleSpellHighlighting(bool on);
 
+    void setDefinition(const KSyntaxHighlighting::Definition &def) override;
+
     /**
      * Reimplemented to highlight quote blocks.
      */
     void highlightBlock(const QString &text) override;
 
-    void setSyntaxHighlighterRules(const QVector<KPIMTextEdit::Rule> &rule);
 protected:
     /**
      * Reimplemented, the base version sets the text color to black, which
@@ -59,9 +64,8 @@ protected:
      */
     void setMisspelled(int start, int count) override;
 
-    virtual bool spellCheckBlock(const QString &text);
+    void applyFormat(int offset, int length, const KSyntaxHighlighting::Format &format) override;
 private:
-    class PlainTextSyntaxSpellCheckingHighlighterPrivate;
     PlainTextSyntaxSpellCheckingHighlighterPrivate *const d;
 };
 }
