@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,7 +20,6 @@
 #include "richtexteditfindbar.h"
 #include "texteditor/commonwidget/textfindreplacewidget.h"
 
-#include <KLocalizedString>
 #include <kmessagebox.h>
 #include <klineedit.h>
 #include <KColorScheme>
@@ -34,15 +33,14 @@ public:
     RichTextEditFindBarPrivate(QTextEdit *view)
         : mView(view)
     {
-
     }
 
-    QTextEdit *mView;
+    QTextEdit *mView = nullptr;
 };
 
 RichTextEditFindBar::RichTextEditFindBar(QTextEdit *view, QWidget *parent)
-    : TextEditFindBarBase(parent),
-      d(new KPIMTextEdit::RichTextEditFindBarPrivate(view))
+    : TextEditFindBarBase(parent)
+    , d(new KPIMTextEdit::RichTextEditFindBarPrivate(view))
 {
 }
 
@@ -74,6 +72,13 @@ bool RichTextEditFindBar::searchInDocument(const QString &text, QTextDocument::F
     return found;
 }
 
+bool RichTextEditFindBar::searchInDocument(const QRegExp &regExp, QTextDocument::FindFlags searchOptions)
+{
+    const bool found = d->mView->find(regExp, searchOptions);
+    mFindWidget->setFoundMatch(found);
+    return found;
+}
+
 void RichTextEditFindBar::autoSearchMoveCursor()
 {
     QTextCursor cursor = d->mView->textCursor();
@@ -85,10 +90,18 @@ void RichTextEditFindBar::slotReplaceText()
 {
     //FIXME!
     if (d->mView->textCursor().hasSelection()) {
-        if (d->mView->textCursor().selectedText() == mFindWidget->search()->text()) {
-            d->mView->textCursor().insertText(mReplaceWidget->replace()->text());
-            //search next after replace text.
-            searchText(false, false);
+        if (mFindWidget->isRegularExpression()) {
+            if (d->mView->textCursor().selectedText().contains(mFindWidget->searchRegExp())) {
+                d->mView->textCursor().insertText(mReplaceWidget->replaceLineEdit()->text());
+                //search next after replace text.
+                searchText(false, false);
+            }
+        } else {
+            if (d->mView->textCursor().selectedText() == mFindWidget->searchText()) {
+                d->mView->textCursor().insertText(mReplaceWidget->replaceLineEdit()->text());
+                //search next after replace text.
+                searchText(false, false);
+            }
         }
     } else {
         searchText(false, false);
@@ -97,9 +110,12 @@ void RichTextEditFindBar::slotReplaceText()
 
 void RichTextEditFindBar::slotReplaceAllText()
 {
-    //FIXME richtext
-    const QString newText = d->mView->toPlainText().replace(mFindWidget->findRegExp(), mReplaceWidget->replace()->text());
+    QString newText;
+    if (mFindWidget->isRegularExpression()) {
+        newText = d->mView->toPlainText().replace(mFindWidget->searchRegExp(), mReplaceWidget->replaceLineEdit()->text());
+    } else {
+        newText = d->mView->toPlainText().replace(mFindWidget->searchText(), mReplaceWidget->replaceLineEdit()->text());
+    }
     d->mView->selectAll();
     d->mView->insertPlainText(newText);
 }
-
